==> libreoffice-still-sdk-7.5.9-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/all_6.js <==
var searchData=
[
  ['factory_2ehxx_0',['factory.hxx',['../a00386.html',1,'']]],
  ['fetchfilestatus_1',['fetchFileStatus',['../a00578.html#a6e0c84f5fdf2f5402e331d869d81d771',1,'salhelper::LinkResolver']]],
  ['fields_2',['Fields',['../a00838.html#a5b37495c700c2622059361faad0f45b5',1,'oslProcessInfo']]],
  ['fields_20to_20retrieve_20by_20osl_5fgetfilestatus_3',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['fields_20to_20retrieve_20by_20osl_5fgetvolumeinfo_4',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['fifo_5',['Fifo',['../a00786.html#a17884cd168469537e71c44a0813c8d2ba0717627d4165f4ea9656bbb0017e1a7b',1,'osl::FileStatus']]],
  ['file_6',['file',['../a00790.html',1,'osl::File'],['../a00790.html#adecbedaa84519a863718f598fbe1f304',1,'osl::File::File()']]],
  ['file_20attributes_7',['File attributes',['../a00522.html',1,'']]],
  ['file_20types_8',['File types',['../a00521.html',1,'']]],
  ['file_2eh_9',['file.h',['../a00179.html',1,'']]],
  ['file_2ehxx_10',['file.hxx',['../a00182.html',1,'']]],
  ['filebase_11',['FileBase',['../a00774.html',1,'osl']]],
  ['filestatus_12',['filestatus',['../a00786.html#af1dfb081f9b416f8bb02cd52021e9807',1,'osl::FileStatus::FileStatus()'],['../a00786.html',1,'osl::FileStatus']]],
  ['fillhandles_13',['fillhandles',['../a01898.html#a9debfb1b33367ae074d60ca741d85484',1,'cppu::IPropertyArrayHelper::fillHandles()'],['../a01902.html#a3cdc4c4a14e308524b059dae14bec2db',1,'cppu::OPropertyArrayHelper::fillHandles(sal_Int32 *pHandles, const css::uno::Sequence&lt; ::rtl::OUString &gt; &amp;rPropNames) SAL_OVERRIDE']]],
  ['fillpropertymembersbyhandle_14',['fillpropertymembersbyhandle',['../a01902.html#ae3f2f04cc07b3fae60012e04947b79ff',1,'cppu::OPropertyArrayHelper::fillPropertyMembersByHandle()'],['../a01898.html#a8c04f99f1bfcb4a9a43e5f2edc19eb70',1,'cppu::IPropertyArrayHelper::fillPropertyMembersByHandle()']]],
  ['findsofficepath_2eh_15',['findsofficepath.h',['../a00392.html',1,'']]],
  ['fire_16',['fire',['../a01922.html#acf944b3cbcb5c73293544577c02c9a0b',1,'cppu::OPropertySetHelper']]],
  ['fireevents_17',['fireEvents',['../a01918.html#a4623d158820924662d580db19642e2b6',1,'cppu::IEventNotificationHook']]],
  ['firepropertieschangeevent_18',['firePropertiesChangeEvent',['../a01922.html#a391277f90c4f5fda2d84e623bd03e520',1,'cppu::OPropertySetHelper']]],
  ['flags_19',['Flags',['../a00734.html#add49df45274594fc80abab3396d57f88',1,'_rtl_TextEncodingInfo']]],
  ['flags_20specifying_20which_20fields_20to_20retrieve_20by_20osl_5fgetfilestatus_20',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['flags_20specifying_20which_20fields_20to_20retrieve_20by_20osl_5fgetvolumeinfo_21',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['flush_22',['flush',['../a00842.html#a9032904067012aaa9a96f404f37f63db',1,'osl::Profile']]],
  ['foreach_23',['forEach',['../a01862.html#aa9b910da1b84dff5b1448b29fa5fc114',1,'cppu::OInterfaceContainerHelper']]],
  ['fromutf8_24',['fromUtf8',['../a00754.html#a20215889e232b382981afeaf5cb6dc77',1,'rtl::OUString']]],
  ['functionality_25',['Basic logging functionality.',['../a02496.html',1,'']]]
];

==> libreoffice-still-sdk-24.2.7-2.1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/all_6.js <==
var searchData=
[
  ['factory_2ehxx_0',['factory.hxx',['../a00380.html',1,'']]],
  ['fetchfilestatus_1',['fetchFileStatus',['../a00578.html#a6e0c84f5fdf2f5402e331d869d81d771',1,'salhelper::LinkResolver']]],
  ['fields_2',['Fields',['../a00838.html#a5b37495c700c2622059361faad0f45b5',1,'oslProcessInfo']]],
  ['fields_20to_20retrieve_20by_20osl_5fgetfilestatus_3',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['fields_20to_20retrieve_20by_20osl_5fgetvolumeinfo_4',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['fifo_5',['Fifo',['../a00786.html#a17884cd168469537e71c44a0813c8d2ba0717627d4165f4ea9656bbb0017e1a7b',1,'osl::FileStatus']]],
  ['file_6',['File',['../a00790.html',1,'osl::File'],['../a00790.html#adecbedaa84519a863718f598fbe1f304',1,'osl::File::File()']]],
  ['file_20attributes_7',['File attributes',['../a00522.html',1,'']]],
  ['file_20types_8',['File types',['../a00521.html',1,'']]],
  ['file_2eh_9',['file.h',['../a00179.html',1,'']]],
  ['file_2ehxx_10',['file.hxx',['../a00182.html',1,'']]],
  ['filebase_11',['FileBase',['../a00774.html',1,'osl']]],
  ['filestatus_12',['FileStatus',['../a00786.html',1,'osl::FileStatus'],['../a00786.html#af1dfb081f9b416f8bb02cd52021e9807',1,'osl::FileStatus::FileStatus()']]],
  ['fillhandles_13',['fillHandles',['../a01898.html#a9debfb1b33367ae074d60ca741d85484',1,'cppu::IPropertyArrayHelper::fillHandles()'],['../a01902.html#a3cdc4c4a14e308524b059dae14bec2db',1,'cppu::OPropertyArrayHelper::fillHandles()']]],
  ['fillpropertymembersbyhandle_14',['fillPropertyMembersByHandle',['../a01898.html#a8c04f99f1bfcb4a9a43e5f2edc19eb70',1,'cppu::IPropertyArrayHelper::fillPropertyMembersByHandle()'],['../a01902.html#ae3f2f04cc07b3fae60012e04947b79ff',1,'cppu::OPropertyArrayHelper::fillPropertyMembersByHandle()']]],
  ['findsofficepath_2eh_15',['findsofficepath.h',['../a00395.html',1,'']]],
  ['fire_16',['fire',['../a01922.html#acf944b3cbcb5c73293544577c02c9a0b',1,'cppu::OPropertySetHelper']]],
  ['fireevents_17',['fireEvents',['../a01918.html#a4623d158820924662d580db19642e2b6',1,'cppu::IEventNotificationHook']]],
  ['firepropertieschangeevent_18',['firePropertiesChangeEvent',['../a01922.html#a391277f90c4f5fda2d84e623bd03e520',1,'cppu::OPropertySetHelper']]],
  ['flags_19',['Flags',['../a00734.html#add49df45274594fc80abab3396d57f88',1,'_rtl_TextEncodingInfo']]],
  ['flags_20specifying_20which_20fields_20to_20retrieve_20by_20osl_5fgetfilestatus_20',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['flags_20specifying_20which_20fields_20to_20retrieve_20by_20osl_5fgetvolumeinfo_21',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['flush_22',['flush',['../a00842.html#a9032904067012aaa9a96f404f37f63db',1,'osl::Profile']]],
  ['foreach_23',['forEach',['../a01862.html#aa9b910da1b84dff5b1448b29fa5fc114',1,'cppu::OInterfaceContainerHelper']]],
  ['fromutf8_24',['fromUtf8',['../a00754.html#a20215889e232b382981afeaf5cb6dc77',1,'rtl::OUString']]],
  ['functionality_25',['Basic logging functionality.',['../a02496.html',1,'']]]
];
